@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0510';
+our $VERSION = '0.0511';
 
 use Moo;
 use strictures 2;
@@ -152,7 +152,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0510
+version 0.0511
 
 =head1 SYNOPSIS
 
@@ -163,7 +163,7 @@ version 0.0510
   my $mdp = Music::Duration::Partition->new(
     size    => 8,
     pool    => [qw/ qn en sn /],
-    weights => [ 0.2, 0.3, 0.5 ],
+    weights => [ 0.2, 0.3, 0.5 ], # Optional
   );
 
   $mdp->pool_select( sub { ... } ); # Optional
@@ -180,7 +180,7 @@ version 0.0510
 
   $score->write_score('motif.mid');
 
-  # The pool may also be made of MIDI durations
+  # The size and pool may also be made of MIDI durations
   $mdp = Music::Duration::Partition->new(
     size => 100,
     pool => [qw/ d50 d25 /],
